@@ -121,5 +121,5 @@ class S3Storage:
         with gzip.open(fp, mode='rb') as gz:
             kwargs = {"ACL": self.acl} if self.acl else {}
             self.s3_client.put_object(
-                Bucket=self.bucketname, Key=self.path+keyname,ContentEncoding='gzip', Body=gz, **kwargs
-            )
+                Bucket=self.bucketname, Key=self.path+keyname, Body=gz, **kwargs
+            )
\ No newline at end of file
